summaryrefslogtreecommitdiffstats
path: root/Lib/importlib
diff options
context:
space:
mode:
authorEric Snow <ericsnowcurrently@gmail.com>2016-05-27 18:36:28 (GMT)
committerEric Snow <ericsnowcurrently@gmail.com>2016-05-27 18:36:28 (GMT)
commitfc36e66af46957a65b12ab0087027727f8555aed (patch)
tree4254a831fec50bef9b65782120bd6e6bb84baad3 /Lib/importlib
parentc618ae8ed79cf391efa62b7d0ed571882a4356f9 (diff)
downloadcpython-fc36e66af46957a65b12ab0087027727f8555aed.zip
cpython-fc36e66af46957a65b12ab0087027727f8555aed.tar.gz
cpython-fc36e66af46957a65b12ab0087027727f8555aed.tar.bz2
Issue #27138: Fix the doc comment for FileFinder.find_spec().
Diffstat (limited to 'Lib/importlib')
-rw-r--r--Lib/importlib/_bootstrap_external.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/importlib/_bootstrap_external.py b/Lib/importlib/_bootstrap_external.py
index ef13fd2..9788828 100644
--- a/Lib/importlib/_bootstrap_external.py
+++ b/Lib/importlib/_bootstrap_external.py
@@ -1213,8 +1213,8 @@ class FileFinder:
submodule_search_locations=smsl)
def find_spec(self, fullname, target=None):
- """Try to find a loader for the specified module, or the namespace
- package portions. Returns (loader, list-of-portions)."""
+ """Try to find a spec for the specified module. Returns the
+ matching spec, or None if not found."""
is_namespace = False
tail_module = fullname.rpartition('.')[2]
try: